pilas.lanzador.Ventana

Package pilas :: Module lanzador :: Class Ventana |
[hide private]
[frames] | no frames]

# Class Ventana

source code

                 object --+
                          |
    lanzador_base.Ui_Dialog --+
                              |
                             Ventana

Instance Methods | [hide private]
setupUi(self, Dialog) | source code
acepta(self) | source code
obtener_seleccion(self) | source code
_quitar_barras_scroll(self) | source code
mostrar_imagen(self, ruta) | source code
Inherited from `lanzador_base.Ui_Dialog`: `retranslateUi` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### setupUi(self, Dialog) | source code
Overrides: lanzador_base.Ui_Dialog.setupUi